@@ -23,14 +23,19 @@ class ParamsValueError(ValueError):
     def form_message(self, fuzzy=False):  # noqa: disable
         """ format error message
         """
-        message = "参数验证失败，请检查您的输入!"
+        message = "Parameter verification failed, please check your input"
 
         # 模糊错误信息
         if fuzzy:
             return message
 
+        # read formatted message from  context
+        message = self.context.get("message") or message
+
         # read filter object
-        filter_obj = self.context["filter"]
+        filter_obj = self.context.get("filter")
+        if not filter_obj:
+            return message
 
         # Read formatter message from custom filter
         filter_fmt_msg = filter_obj.fmt_error_message(self.code)
