@@ -26,31 +26,28 @@ class EqualKeyFilter(BaseFilter):
         :param code: 错误码
         """
         if code == 593:
-            return "'%s'与'%s'值必须相同" % (self.key, self.rule.eq_key)
+            return "the value of '%s' must be the same as the value of '%s'" % (self.key, self.rule.eq_key)
 
         if code == 594:
-            return "'%s'与'%s'值不允许相同" % (self.key, self.rule.neq_key)
+            return "the value of '%s' must be different from the value of '%s'" % (self.key, self.rule.neq_key)
 
         if code == 595:
-            return "'%s'应该大于'%s'" % (self.key, self.rule.gt_key)
+            return "the value of '%s' must be greater than the value of'%s'" % (self.key, self.rule.gt_key)
 
         if code == 596:
-            return "'%s'应该大于等于'%s'" % (self.key, self.rule.gte_key)
+            return "the value of '%s' must be greater than or equal to the value of'%s'" % (self.key, self.rule.gte_key)
 
         if code == 597:
-            return "'%s'应该小于'%s'" % (self.key, self.rule.lt_key)
+            return "the value of '%s' must be less than the value of'%s'" % (self.key, self.rule.lt_key)
 
         if code == 598:
-            return "'%s'应该小于等于'%s'" % (self.key, self.rule.lte_key)
+            return "the value of '%s' must be less than or equal to the value of'%s'" % (self.key, self.rule.lte_key)
 
-        return "过滤器'EqualKeyFilter'过滤器检查'%s'参数失败" % self.key
+        return "%s field fails the 'EqualKeyFilter' filter check" % self.key
 
     def filter_required(self):
         """ 验证是否需要进行过滤
         """
-        if not self.rule.required and self.value is None:
-            return False
-
         if self.rule.eq_key is not None or self.rule.neq_key is not None:
             return True
 
@@ -71,14 +68,21 @@ class EqualKeyFilter(BaseFilter):
         params = kwargs.get("params", dict())
         value = get_deep_value(self.rule.key_map or self.key, params, None, deep=True)
 
+        # BUG: complex filter value will be None
+        if not self.rule.required and (value == self.rule.default or value is None):
+            return value
+
         for r_key, r_code in self.support_rules.items():
-            rule = getattr(self.rule, r_key, None)
+            other_key = getattr(self.rule, r_key, None)
 
             # 当前规则不需要处理
-            if rule is None:
+            if other_key is None:
                 continue
 
-            other_v = get_deep_value(rule, params, None, deep=True)
+            other_v = get_deep_value(other_key, params, None, deep=True)
+            # 如果other_v是None，则说明other_key允许为空，并且用户未填写
+            if other_v is None:
+                continue
 
             if not isinstance(other_v, self.rule.direct_type):
                 raise TypeError("'eq_key' 规则仅支持相同数据类型参数判断")
