@@ -15,12 +15,13 @@ class RegexpFilter(BaseFilter):
     """
     正则表达式过滤器
     """
+
     error_code = 566
 
     def fmt_error_message(self, _):
         """ 格式化错误消息
         """
-        return "%s字段不符合格式要求!" % self.key
+        return "%s field does not confirm to regular expression" % self.key
 
     def filter_required(self):
         """ 检查过滤器是否必须执行
